@@ -14,7 +14,7 @@ use MIME::Base64 qw(encode_base64);
 use App::Followme::FIO;
 use App::Followme::NestedText;
 
-our $VERSION = "2.00";
+our $VERSION = "2.01";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -96,7 +96,7 @@ sub file_info {
 # Set exclude_index to true and set default date format
 
 sub setup {
-    my ($self, %configuration) = @_;
+    my ($self) = @_;
 
     $self->{data}{date_format} ||= 'Day, dd Mon yyyy';
     $self->{data}{exclude_index} = 1;
